==> kmago-1.1.tar.gz: kmago-1.1/kmago/ktransferkio.cpp <==
/***************************************************************************
                          ktransferkio.cpp  -  description
                             -------------------
    begin                : Sun Nov 5 2000
    copyright            : (C) 2000 by Sergio Moretti
    email                : sermore@libero.it
    revision             : $Revision: 1.4 $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef ENABLE_KIO

#include "ktransferkioimpl.h"
#include "ktransferkio.h"

KTransferKio::KTransferKio(KTransferKioImpl *impl) : KTransfer(impl) 
{
}

KTransferKioImpl * KTransferKio::impl() const 
{
   return dynamic_cast<KTransferKioImpl*>(KTransfer::impl());
}
 
// config

bool KTransferKio::getDisableCookie() const
{
   return impl()->getDisableCookie();
}

void KTransferKio::setDisableCookie(bool v) const
{
   impl()->setDisableCookie(v);
}

#endif

==> kmago-1.1.1.tar.gz: kmago-1.1.1/kmago/ktransferkio.cpp <==
/***************************************************************************
                          ktransferkio.cpp  -  description
                             -------------------
    begin                : Sun Nov 5 2000
    copyright            : (C) 2000 by Sergio Moretti
    email                : sermore@libero.it
    revision             : $Revision: 1.5 $
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef ENABLE_KIO

#include "ktransferkioimpl.h"
#include "ktransferkio.h"

KTransferKio::KTransferKio(KTransferKioImpl *impl) : KTransfer(impl) 
{
}

KTransferKioImpl * KTransferKio::impl() const 
{
   return dynamic_cast<KTransferKioImpl*>(KTransfer::impl());
}
 
// config

bool KTransferKio::getDisableCookie() const
{
   return impl()->getDisableCookie();
}

void KTransferKio::setDisableCookie(bool v) const
{
   impl()->setDisableCookie(v);
}

bool KTransferKio::getDisableCache() const
{
   return impl()->getDisableCache();
}

void KTransferKio::setDisableCache(bool v) const
{
   impl()->setDisableCache(v);
}

#endif
